<?php
/*
Plugin Name: Da Stop Words Removal
Description: Improve your SEO ranking with Google, bing, Yahoo! and all the search engine by removing all the stop words in your slug - also called permalink. 
When you'll have install Da Stop Word Removal, you'll be able to remove all commun stop words due to the list included in the plugin.
Version: 0.2
Author: Inside da Web
Author URI: http://www.insidedaweb.com/
*/

global $dswr_db_version;
global $dswr_table_lists;
global $dswr_table_words;
global $dswr_version;

$dswr_db_version = "2.0";
$dswr_version = "0.2";
$dswr_table_lists = "dswr_lists";
$dswr_table_words = "dswr_words";

define( 'DSWR_PLUGIN_PATH', plugin_dir_path(__FILE__) );
define( 'DSWR_PLUGIN_URL', plugin_dir_url(__FILE__) );

function dswr_get_lists_table(){
	global $wpdb;
	global $dswr_table_lists;
	return $wpdb->prefix . $dswr_table_lists;
}

function dswr_get_words_table(){
	global $wpdb;
	global $dswr_table_words;
	return $wpdb->prefix . $dswr_table_words;
}

function dswr_install(){
	global $wpdb;
	global $dswr_db_version;
	$table_lists = dswr_get_lists_table();
	$table_words = dswr_get_words_table();
	$installed_ver = get_option( "dswr_db_version" );

	if( $installed_ver != $dswr_db_version ){
		$sql_lists = "CREATE TABLE $table_lists (
		  id bigint(20) NOT NULL AUTO_INCREMENT,
		  name varchar(255) DEFAULT '',
		  visible TINYINT(1) DEFAULT '1',
		  created datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
		  PRIMARY KEY  id (id)
		) CHARACTER SET utf8 COLLATE utf8_general_ci";

		$sql_words = "CREATE TABLE $table_words (
		  id bigint(20) NOT NULL AUTO_INCREMENT,
		  word varchar(255) DEFAULT '',
		  list bigint(20),
		  PRIMARY KEY  id (id)
		) CHARACTER SET utf8 COLLATE utf8_general_ci;";

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $sql_lists );
		dbDelta( $sql_words );

		update_option( "dswr_db_version", $dswr_db_version );

		if( get_option( 'dswr_add_initial_list' ) != '1' ){
			dswr_add_initial_list();
		}
	}
}

// Install database
register_activation_hook( __FILE__, 'dswr_install' );

function dswr_update_db_check(){
	global $dswr_db_version;
	global $dswr_version;
    if ( get_option( 'dswr_db_version' ) != $dswr_db_version ) {
        dswr_install();
    }
    if ( get_option( 'dswr_version' ) != $dswr_version ) {
        dswr_add_initial_list();
    }
}

// Update if needed
add_action( 'plugins_loaded', 'dswr_update_db_check' );

function dswr_list_name_exists( $list_name ){
	global $wpdb;
	$table_lists = dswr_get_lists_table();
	$sql = "SELECT COUNT(id) FROM $table_lists WHERE name = '$list_name'";
	$count = $wpdb->get_var( $sql );
	if( $count == 1 ){
		return true;
	}else{
		return false;
	}
}

function dswr_add_initial_list(){
	global $dswr_version;
	foreach ( glob( DSWR_PLUGIN_PATH . "lists/*.txt" ) as $list ){
		$list_name = basename( $list, '.txt' );
		if( !dswr_list_name_exists( $list_name ) ){
			$list_id = dswr_add_new_list( $list_name );
        	$words = dswr_read_words_from_file( $list );
        	dswr_add_words_array( $words, $list_id );
    	}
    }
    update_option( "dswr_add_initial_list", '1' );
    update_option( "dswr_version", $dswr_version );
}

function dswr_read_words_from_file( $filename ){
	if(!file_exists( $filename ) || !is_readable( $filename ) )
        return false;

    $line_size = 0;
    $delimiter = ',';
    $enclosure ='';
    $data = array();

    ini_set('auto_detect_line_endings', true);

    if (($handle = fopen($filename, 'r')) !== false){
    	while (($row = fgetcsv($handle, $line_size, $delimiter, chr(0))) !== false){
    		$num = count($row);
            for ($i=0; $i < $num; $i++) {
	            $data[] = dswr_sanitize_input( $row[$i] );
	        }
        }
        fclose($handle);
    }

    return $data;
}

function dswr_sanitize_input( $input ){
	return esc_sql( str_replace("’", "'", trim( $input ) ) );
}

function dswr_add_words_array( $words, $list_id ){
	global $wpdb;
	$table_words = dswr_get_words_table();

	if( is_array( $words ) && count( $words ) > 0 ){
		$sql = "INSERT INTO $table_words (word,list) VALUES";
		$sql_words = '';
		foreach ( $words as $word ) {
			$sql_words .= ( $sql_words == '' ) ? ' ' : ', ';
			$sql_words .= " ('$word', '$list_id')";
		}

		$sql .= $sql_words;
	}
	// echo $sql;
	// exit();
	return $wpdb->query( $sql );
}

function dswr_load_scripts(){
	wp_enqueue_style( 'dswr-style', DSWR_PLUGIN_URL .'css/dswr-style.css' );
	wp_enqueue_script( 'dswr-script', DSWR_PLUGIN_URL .'js/dswr-script.js', array('jquery') );
}
add_action( 'admin_init', 'dswr_load_scripts' );

require DSWR_PLUGIN_PATH . 'inc/settings.php';
require DSWR_PLUGIN_PATH . 'inc/ajax.php';
?>